##################################################################################################################################
# Requires: For  use in Orchid Info Manager Notes - 
# Script is to be applied to AR1700 Customer Inquiry, to the field 'CUSTOMER NO.' field label in Notes/DML Hotkey setup
# Data is displayed in a grid in the Note and in an EB Note that displays the long comment.
# Comments are sorted in reverse entry date order by using a browse and fetch in reverse order.
# --------------------------------------------------------------------------------------------------------------------------------
# Copyright 2022 Orchid Systems 
#
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
# ------------------------------------------
##################################################################################################################################


from accpac import *

import eb

import datetime
import locale
import time

arcus = None
grid = None
cmntBox = None

#read the parameter passed in the Notes/DML Hotkey setup
myparam = None
def init(p):

	global myparam
	myparam = p

def accpacDateToDate(d):
	if d == "0":
		return None
	return datetime.date(int(d[0:4]), int(d[4:6]), int(d[6:8]))

def onRefreshContent():
	global arcus
	global custid

	locale.setlocale(locale.LC_ALL, "")
	now = time.strftime("%Y%m%d")
	eb.clearAll()

	if len(eb.value1.strip()) == 0:
		return
	custid = eb.value1.strip()
	# read default values from customer record.
	#showMessageBox("customer " + custid)
	try:
		if (custid != ""): 
			t = getCustComments(custid)
			eb.showAlertBox()
		else:
			t = "    "
			note = eb.addNote(t)
			note.category = "ARCMM"
			
	except Exception as ex:
		showMessage("Exception error occurred when finding customer comments: " + str(ex))
		
def grid_onRowChanged(newRow):
	global cmntBox
	global grid
	
	cmntBox.setText(grid.getCellValue(4))
	cmntBox.setCategory("ARCMM")

def getCustComments(custid):
	global grid
	global cmntBox
	global myparam
	
	t = ""
	grid = None
	
	#showMessage ("Item /customer in Plan table" + str(qtycovered))
	t = t + "AR Comments "  + "\r\n"

	sFilter = "IDCUST = \"{}\" AND DATEEXPR >= {}".format(custid, sessionDate())
	
	## if comment types are supplied in the parameters, split into a list with no whitespace.
	commentTypes = [x.strip().upper() for x in myparam.split(',')]	## returns a list object.
	if len(commentTypes) > 0:
		sFilter += " AND ({})"
		s = ""
		for idx, x in enumerate(commentTypes):
			if idx > 0:
				s += " OR "
			s += "(CMNTTYPE = \"{}\")".format(x)
		if s:
			sFilter = sFilter.format(s)
			
	#showMessageBox(sFilter, "filter")
	
	try:
		v = openView("AR0021", 1)
		r = v.recordClear()
		if r == 0:
			## Need to put into the field with Verify = 0
			## i.e. do not verify since customer ZZZZZZZZZZZZ does not exist.
			r = v.put("IDCUST", "ZZZZZZZZZZZZ", 0)
		if r == 0:
			r = v.put("DATEENTR", "20991231")
		if r == 0:
			r = v.put("CNTUNIQ",999)
		if r:
			errmsg = showErrorMsgs(True)
			showMessageBox(errmsg)
			
		v.browse(sFilter, 0)
		while v.fetch() == 0:
			if grid is None:
				grid = eb.addGrid()
				grid.name = "grid"
				grid.onRowChanged = grid_onRowChanged
				col = grid.addColumn("Entered by")
				col = grid.addColumn("Entered Date")
				col = grid.addColumn("Follow-up Date")
				col = grid.addColumn("Expiry Date")
				col = grid.addColumn("Comment")
				col.align = "LEFT"

			## v.get(someDateField) returns a date object that can be converted to a string using the local date format setting.
			sDateentr = dateToString(v.get("DATEENTR"))
			sDateFU = dateToString(v.get("DATEFLUP"))
			sDateExpiry = dateToString(v.get("DATEEXPR"))
			
			r = grid.addRow()
			r.setCell(0, v.get("USERID").rstrip())
			r.setCell(1, sDateentr)
			r.setCell(2, sDateFU)
			r.setCell(3, sDateExpiry)
			r.setCell(4, v.get("TEXTCMNT").strip())
	
	except Exception as ex:
		showMessageBox(str(ex))
	
	try:
		if grid:
			## Add a text box to display the long comment from the first line.
			cmntBox = eb.addNote()
			cmntBox.setHeading("Comment")
			if len(grid.rows) > 0:
				grid.selectRow(0)
				cmntBox.setText(grid.getCellValue(4))
				cmntBox.setCategory("ARCMM")
				
	except Exception as ex:
		showMessageBox("Error: " + str(ex))
		
	return t
 
############## showErrorMsgs ###########
## Returns the stack errors in line separated format.
def showErrorMsgs(bClearStack = False):
	
	errStack = getErrorStack()
	cnt = int(errStack.count())
	
	msg = ""
	fullmsg = ""
	if cnt > 0:
		i = 0
		for i in range(0, errStack.count()):
			msg = str(errStack.getText(i)).strip()
			if msg != "":
				fullmsg = fullmsg + "\n" + msg
			
		if bClearStack == True:
			errStack.clear()
	
	if fullmsg != "":
		fullmsg = fullmsg[1:]
		
	return fullmsg.strip()
